@@ -9,15 +9,22 @@ local function quote_if_needed (s)
     return s
 end
 
+local function print_exit(msg)
+    print()
+    print(string.rep("*",#msg + 4))
+    print("* "..msg.." *")
+    print(string.rep("*",#msg + 4))
+end
+
 -- get the Lua command-line used to invoke this script
 local cmd = app.lua()
 
 function do_lua_files ()
     for _,f in ipairs(dir.getfiles('.','*.lua')) do
         print(cmd..' '..f)
-        local res = utils.execute(cmd..' '..f)
+        local res,code = utils.execute(cmd..' '..f)
         if not res then
-            print ('process failed with non-zero result: '..f)
+            print_exit ('process failed with non-zero result: ['..code..'] '..f)
             os.exit(1)
         end
     end
